package model

import (
	"slices"
	"strings"

	"github.com/pocketbase/pocketbase/models"
	"github.com/pocketbase/pocketbase/tools/types"
)

type Events []Event

func (m Events) Contains(event Event) bool {
	return slices.Contains(m, event)
}

type AnonymizedEventDTO struct {
	Day   string         `db:"Day" json:"day"`
	Week  string         `db:"Week" json:"week"`
	Start types.DateTime `db:"start" json:"start"`
	End   types.DateTime `db:"end" json:"end"`
	Rooms string         `db:"Rooms" json:"rooms"`
	Free  bool           `json:"free"`
}

type Event struct {
	UUID       string         `db:"uuid" json:"uuid"`
	Day        string         `db:"Day" json:"day"`
	Week       string         `db:"Week" json:"week"`
	Start      types.DateTime `db:"start" json:"start"`
	End        types.DateTime `db:"end" json:"end"`
	Name       string         `db:"Name" json:"name"`
	EventType  string         `db:"EventType" json:"eventType"`
	Compulsory string         `db:"Compulsory" json:"compulsory"`
	Prof       string         `db:"Prof" json:"prof"`
	Rooms      string         `db:"Rooms" json:"rooms"`
	Notes      string         `db:"Notes" json:"notes"`
	BookedAt   string         `db:"BookedAt" json:"bookedAt"`
	Course     string         `db:"course" json:"course"`
	Semester   string         `db:"semester" json:"semester"`
	models.BaseModel
}

func (m *Event) Equals(event Event) bool {
	return m.Day == event.Day &&
		m.Week == event.Week &&
		m.Start == event.Start &&
		m.End == event.End &&
		m.Name == event.Name &&
		m.Course == event.Course &&
		m.Prof == event.Prof &&
		m.Rooms == event.Rooms &&
		m.EventType == event.EventType
}

func (m *Event) TableName() string {
	return "events"
}

// SetCourse func to set the course and returns the event
func (m *Event) SetCourse(course string) Event {
	m.Course = course
	return *m
}

// Creates an AnonymizedEventDTO from an Event hiding all sensitive data
func (m *Event) AnonymizeEvent() AnonymizedEventDTO {
	return AnonymizedEventDTO{
		Day:   m.Day,
		Week:  m.Week,
		Start: m.Start,
		End:   m.End,
		Rooms: m.Rooms,
		Free:  strings.Contains(strings.ToLower(m.Name), "zur freien verfügung"),
	}
}
