package service

import (
	"github.com/pocketbase/pocketbase"
	"github.com/pocketbase/pocketbase/core"
	"github.com/pocketbase/pocketbase/tools/cron"
	"htwkalender/service/course"
	"htwkalender/service/events"
	"htwkalender/service/feed"
	"htwkalender/service/fetch/sport"
	v2 "htwkalender/service/fetch/v2"
	"htwkalender/service/functions/time"
	"log"
	"strconv"
)

func AddSchedules(app *pocketbase.PocketBase) {

	app.OnBeforeServe().Add(func(e *core.ServeEvent) error {
		scheduler := cron.New()

		// Every hour update all courses (5 segments - minute, hour, day, month, weekday) "0 * * * *"
		// Every three hours update all courses (5 segments - minute, hour, day, month, weekday) "0 */3 * * *"
		// Every 10 minutes update all courses (5 segments - minute, hour, day, month, weekday) "*/10 * * * *"
		scheduler.MustAdd("updateCourse", "0 */3 * * *", func() {
			course.UpdateCourse(app)
		})

		// Every sunday at 1am clean all courses (5 segments - minute, hour, day, month, weekday) "0 3 * * 0"
		scheduler.MustAdd("cleanFeeds", "0 1 * * 0", func() {
			// clean feeds older than 6 months
			feed.ClearFeeds(app.Dao(), 6, time.RealClock{})
		})

		// Every sunday at 3am fetch all sport events (5 segments - minute, hour, day, month, weekday) "0 2 * * 0"
		scheduler.MustAdd("fetchSportEvents", "0 3 * * 0", func() {
			sport.FetchAndUpdateSportEvents(app)
		})

		//delete all events and then fetch all events from remote this should be done every sunday at 2am
		scheduler.MustAdd("fetchEvents", "0 2 * * 0", func() {
			err := events.DeleteAllEvents(app)
			if err != nil {
				log.Println(err)
			}

			err, savedEvents := v2.FetchAllEventsAndSave(app)
			if err != nil {
				log.Println(err)
			} else {
				log.Println("Successfully saved: " + strconv.FormatInt(int64(len(savedEvents)), 10) + " events")
			}

		})

		scheduler.Start()
		return nil
	})

}
