package date

import (
	"reflect"
	"testing"
	"time"
)

func Test_getDateFromWeekNumber(t *testing.T) {
	europeTime, _ := time.LoadLocation("Europe/Berlin")

	type args struct {
		year       int
		weekNumber int
		dayName    string
	}
	tests := []struct {
		name    string
		args    args
		want    time.Time
		wantErr bool
	}{
		{
			name: "Test 1",
			args: args{
				year:       2021,
				weekNumber: 1,
				dayName:    "Montag",
			},
			want:    time.Date(2021, 1, 4, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
		{
			name: "Test 2",
			args: args{
				year:       2023,
				weekNumber: 57,
				dayName:    "Montag",
			},
			want:    time.Date(2024, 1, 29, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
		{
			name: "Test 3",
			args: args{
				year:       2023,
				weekNumber: 1,
				dayName:    "Montag",
			},
			want:    time.Date(2023, 1, 2, 0, 0, 0, 0, europeTime),
			wantErr: false,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			got, err := GetDateFromWeekNumber(tt.args.year, tt.args.weekNumber, tt.args.dayName)
			if (err != nil) != tt.wantErr {
				t.Errorf("getDateFromWeekNumber() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !reflect.DeepEqual(got, tt.want) {
				t.Errorf("getDateFromWeekNumber() got = %v, want %v", got, tt.want)
			}
		})
	}
}
