package db

import (
	"github.com/pocketbase/dbx"
	"github.com/pocketbase/pocketbase"
	"github.com/pocketbase/pocketbase/models"
	"htwkalender/model"
)

func SaveGroups(seminarGroup []model.SeminarGroup, collection *models.Collection, app *pocketbase.PocketBase) ([]*models.Record, error) {
	var savedRecords []*models.Record
	var tobeSavedGroups []model.SeminarGroup
	var insertRecords []*models.Record

	for _, group := range seminarGroup {
		dbGroup, err := FindGroupByCourse(group.Course, app)

		if dbGroup == nil && err.Error() == "sql: no rows in result set" {
			tobeSavedGroups = append(tobeSavedGroups, group)
		} else if err != nil {
			return nil, err
		}
	}

	// create record for each group that's not already in the database
	for _, group := range tobeSavedGroups {
		record := models.NewRecord(collection)
		record.Set("university", group.University)
		record.Set("shortcut", group.GroupShortcut)
		record.Set("groupId", group.GroupId)
		record.Set("course", group.Course)
		record.Set("faculty", group.Faculty)
		record.Set("facultyId", group.FacultyId)
		insertRecords = append(insertRecords, record)
	}

	// save all records
	for _, record := range insertRecords {
		if record != nil {
			err := app.Dao().SaveRecord(record)
			if err == nil {
				savedRecords = append(savedRecords, record)
			} else {
				return nil, err
			}
		}
	}

	return savedRecords, nil
}

func FindGroupByCourse(course string, app *pocketbase.PocketBase) (*model.SeminarGroup, error) {
	var group model.SeminarGroup
	err := app.Dao().DB().Select("*").From("groups").Where(dbx.NewExp("course = {:course}", dbx.Params{"course": course})).One(&group)
	if err != nil {
		return nil, err
	}
	return &group, err
}

func GetAllCourses(app *pocketbase.PocketBase) []string {

	var courses []struct {
		CourseShortcut string `db:"course" json:"course"`
	}

	// get all rooms from event records in the events collection
	err := app.Dao().DB().Select("course").From("groups").All(&courses)
	if err != nil {
		print("Error while getting groups from database: ", err)
		return nil
	}

	var courseArray []string

	for _, course := range courses {
		courseArray = append(courseArray, course.CourseShortcut)
	}

	return courseArray
}
