package db

import (
	"fmt"
	"htwkalender/model"
	"htwkalender/service/functions"
	"strings"
	"time"

	"github.com/pocketbase/dbx"
	"github.com/pocketbase/pocketbase"
)

func GetRooms(app *pocketbase.PocketBase) []string {

	var events []struct {
		Rooms string `db:"Rooms" json:"Rooms"`
	}

	// get all rooms from event records in the events collection
	err := app.Dao().DB().Select("Rooms").From("events").All(&events)
	if err != nil {
		print("Error while getting rooms from database: ", err)
		return nil
	}

	var roomArray []string

	for _, event := range events {
		var room = strings.FieldsFunc(event.Rooms, functions.IsSeparator(
			[]rune{',', ' ', '\t', '\n', '\r', '\u00A0'},
		))
		//split functions room by space and add each room to array if it is not already in there
		for _, r := range room {
			var text = strings.TrimSpace(r)
			if !functions.Contains(roomArray, text) && !strings.Contains(text, " ") && len(text) >= 1 {
				roomArray = append(roomArray, text)
			}
		}
	}
	return roomArray
}

func GetRoomScheduleForDay(app *pocketbase.PocketBase, room string, date string) []model.Event {
	var events []model.Event

	// get all events from event records in the events collection
	err := app.Dao().DB().Select("*").From("events").
		Where(dbx.Like("Rooms", room).Escape("_", "_")).
		AndWhere(dbx.Like("Start", date)).
		GroupBy("Week", "Start", "End", "Rooms").
		All(&events)
	if err != nil {
		print("Error while getting events from database: ", err)
		return nil
	}
	return events
}

func GetRoomSchedule(app *pocketbase.PocketBase, room string, from string, to string) []model.Event {
	var events []model.Event

	fromDate, err := time.Parse("2006-01-02", from)
	if err != nil {
		fmt.Println("Error parsing date 'from':", err)
		return nil
	}
	toDate, err := time.Parse("2006-01-02", to)
	if err != nil {
		fmt.Println("Error parsing date 'to':", err)
		return nil
	}

	// get all events from event records in the events collection
	err = app.Dao().DB().Select("*").From("events").
		Where(dbx.Like("Rooms", room).Escape("_", "_")).
		AndWhere(dbx.Between("Start", fromDate, toDate)).
		GroupBy("Week", "Start", "End", "Rooms").
		All(&events)

	if err != nil {
		print("Error while getting events from database: ", err)
		return nil
	}
	return events
}
