package ical

import (
	"bytes"
	"encoding/json"
	"htwkalender/model"
	"htwkalender/service/db"
	"net/http"
	"time"

	"github.com/jordic/goics"
	"github.com/labstack/echo/v5"
	"github.com/pocketbase/pocketbase"
	"github.com/pocketbase/pocketbase/apis"
)

const expirationTime = 5 * time.Minute

func Feed(c echo.Context, app *pocketbase.PocketBase, token string) error {
	var result string
	var responseWriter = c.Response().Writer
	feed, err := db.FindFeedByToken(token, app)
	if feed == nil && err != nil {
		return c.JSON(http.StatusNotFound, err)
	}

	modules := make(map[string]model.FeedCollection)
	var modulesArray []model.FeedCollection
	_ = json.Unmarshal([]byte(feed.Modules), &modulesArray)

	for _, module := range modulesArray {
		modules[module.UUID] = module
	}

	newFeed, err := createFeedForToken(app, modules)
	if err != nil {
		return c.JSON(http.StatusInternalServerError, err)
	}
	result = newFeed.Content

	responseWriter.Header().Set("Content-type", "text/calendar")
	responseWriter.Header().Set("charset", "utf-8")
	responseWriter.Header().Set("Content-Disposition", "inline")
	responseWriter.Header().Set("filename", "calendar.ics")
	writeSuccess(result, responseWriter)
	c.Response().Writer = responseWriter
	return nil
}

func createFeedForToken(app *pocketbase.PocketBase, modules map[string]model.FeedCollection) (*model.FeedModel, error) {
	res := db.GetPlanForModules(app, modules)
	b := bytes.Buffer{}
	goics.NewICalEncode(&b).Encode(IcalModel{Events: res, Mapping: modules})
	feed := &model.FeedModel{Content: b.String(), ExpiresAt: time.Now().Add(expirationTime)}
	return feed, nil
}

func writeSuccess(message string, w http.ResponseWriter) {
	w.WriteHeader(http.StatusOK)
	_, err := w.Write([]byte(message))
	if err != nil {
		return
	}
}

func CreateIndividualFeed(requestBody []byte, app *pocketbase.PocketBase) (string, error) {
	var modules []model.FeedCollection

	err := json.Unmarshal(requestBody, &modules)
	if err != nil {
		return "", apis.NewNotFoundError("Could not parse request body", err)
	}

	var feed model.Feed
	jsonModules, _ := json.Marshal(modules)
	feed.Modules = string(jsonModules)

	collection, dbError := db.FindCollection(app, "feeds")
	if dbError != nil {
		return "", apis.NewNotFoundError("Collection could not be found", dbError)
	}

	record, err := db.SaveFeed(feed, collection, app)
	if err != nil {
		return "", apis.NewNotFoundError("Could not save feed", err)
	}

	return record.Id, nil
}
