import { createI18n } from "vue-i18n";
import en from "./translations/en.json";
import de from "./translations/de.json";
import localeStore from "../store/localeStore.ts";

export const supportedLocales = {
  en: { name: "English" },
  de: { name: "Deutsch" },
};
// Private instance of VueI18n object
let _i18n: any;
// Initializer
function setup() {
  _i18n = createI18n({
    legacy: false,
    locale: localeStore().locale,
    fallbackLocale: "en",
    messages: {
      en,
      de,
    },
  });
  return _i18n;
}

// Sets the active locale.
function setLocale(newLocale: any) {
  _i18n.global.locale = newLocale;
  setDocumentAttributesFor(newLocale);
}

function setDocumentAttributesFor(locale: any) {
  const htmlElement = document.querySelector("html");

  htmlElement?.setAttribute("lang", locale);
}

// Public interface
export default {
  // Expose the VueI18n instance via a getter
  get vueI18n() {
    return _i18n;
  },
  setup,
  setLocale,
};
